# PBH-{math}`\beta`, a code to explore the constraints on PBH abundances and power spectrum.

**Authors:** [Tadeo D. Gómez](https://www.linkedin.com/in/tadeodaguilar/) & [Luis E. Padilla](https://www.linkedin.com/in/luis-enrique-padilla-albores-052087199/)

**Source:** [Source code at GitHub](https://github.com/TadeoDGAguilar/PBHBeta)

**Licence:** [GNU General Public License v2.0](https://www.gnu.org/licenses/old-licenses/gpl-2.0.html). The documentation is licensed under the [GFDL](https://www.gnu.org/licenses/fdl-1.3.en.html).


[![PyPI version](https://badge.fury.io/py/PBHBeta.svg)](https://badge.fury.io/py/PBHBeta) [![License: GPL v2](https://img.shields.io/badge/License-GPL_v2-blue.svg)](https://www.gnu.org/licenses/old-licenses/gpl-2.0.en.html) [![Documentation Status](https://readthedocs.org/projects/pbhbeta/badge/?version=latest)](https://pbhbeta.readthedocs.io/en/latest/?badge=latest) [![arXiv](https://img.shields.io/badge/arXiv-2308.04642v1-f9f107.svg)](https://arxiv.org/pdf/2308.04642.pdf) 

---

The `PBHBeta` library is a computational tool designed to calculate constraints on the abundance of Primordial Black Holes (PBHs) and the power spectrum (PS) in cosmological scenarios featuring a non-standard evolution phase between the end of inflation and Big Bang Nucleosynthesis (BBN). 

```{warning}
This project is under development.
```

```{note}
This code has been tested exclusively with Python version 3.9, and we strongly recommend using it with versions higher than this (Python 3.x and above).
```

The GitHub repository and PyPI package for `PBHBeta` include the essential libraries necessary to run `PBHBeta`. However, these dependencies must be imported into the notebook or console for the functions to become accesible. Refer to the [Requeriments](https://pbhbeta.readthedocs.io/en/latest/Requeriments.html) and [installation](https://pbhbeta.readthedocs.io/en/latest/Installation.html) sections.

# How to cite us

If you use PBH-{math}`\beta`, please cite arXiv: [2308.04642v1](https://arxiv.org/pdf/2308.04642.pdf).


# Changelog
### Versions:

- **1.0.1 (14/08/2023)** Changes were implemented in the names of modules, functions, and classes.
- **1.0 (05/08/2023)** Initial version.


# TO-Do
- Complete the description into documentation to modules and components.


---

![UNAM](docs/img/UNAM.png){.bg-warning w=100px h=130px}
![ICF](docs/img/ICF.png){.bg-warning w=250px h=130px}
![ICTP](docs/img/ICTP.svg){.bg-warning w=130px h=130px}
![CONAHCYT](docs/img/CONAHCYT.svg){.bg-warning w=190px h=130px}

